/*
 * LookAndFeelOptionPane.java - plugin options pane for LookAndFeel plugin
 * (c) 2001 Dirk Moebius
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import javax.swing.Box;
import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JTextField;
import javax.swing.filechooser.FileFilter;
import org.gjt.sp.jedit.jEdit;
import org.gjt.sp.jedit.AbstractOptionPane;
import org.gjt.sp.jedit.GUIUtilities;
import org.gjt.sp.util.Log;


/**
 * This is the option pane that jEdit displays for the options of
 * the LookAndFeel plugin.
 */
public class LookAndFeelOptionPane extends AbstractOptionPane implements ActionListener
{

    public LookAndFeelOptionPane() {
        super("lookandfeel");
    }


    public void _init() {
        String filename = jEdit.getProperty("lookandfeel.path.themepack");
        if (filename == null) {
            filename = "";
        }
        tThemepack = new JTextField(filename);
        tThemepack.setEditable(false);

        bSelectDir = new JButton(GUIUtilities.loadIcon("Open24.gif"));
        bSelectDir.setMargin(new Insets(0,0,0,0));
        bSelectDir.setToolTipText(jEdit.getProperty("lookandfeel.path.themepack.select"));
        bSelectDir.addActionListener(this);

        bRemoveDir = new JButton(GUIUtilities.loadIcon("Remove24.gif"));
        bRemoveDir.setMargin(new Insets(0,0,0,0));
        bRemoveDir.setToolTipText(jEdit.getProperty("lookandfeel.path.themepack.remove"));
        bRemoveDir.addActionListener(this);

        Box box = Box.createHorizontalBox();
        box.add(tThemepack);
        box.add(bSelectDir);
        box.add(bRemoveDir);

        addComponent(jEdit.getProperty("lookandfeel.path.themepack.label"), box);
    }


    public void _save() {
        String filename = tThemepack.getText();
        if (filename == null || filename.length() == 0) {
            jEdit.unsetProperty("lookandfeel.path.themepack");
        } else {
            File file = new File(filename);
            if (file.exists() && file.canRead()) {
                jEdit.setProperty("lookandfeel.path.themepack", filename);
            } else {
                Log.log(Log.ERROR, this, "themepack file " + filename + " does not exist or is not readable.");
            }
        }
    }


    public void actionPerformed(ActionEvent evt) {
        if (evt.getSource() == bSelectDir) {
            setupFileChooser();
            String filename = tThemepack.getText();
            File oldfile = null;
            if (filename != null && filename.length() > 0) {
                oldfile = new File(filename);
                fChooser.setCurrentDirectory(new File(oldfile.getParent()));
                fChooser.setSelectedFile(oldfile);
            }
            int answer = fChooser.showOpenDialog(this);
            if (answer == JFileChooser.APPROVE_OPTION) {
                File newfile = fChooser.getSelectedFile();
                if (newfile != null && (oldfile == null || !newfile.equals(oldfile))) {
                    if (newfile.exists() && newfile.canRead()) {
                        tThemepack.setText(newfile.getAbsolutePath());
                        GUIUtilities.message(this, "lookandfeel.message.restart", null);
                    } else {
                        GUIUtilities.error(this, "lookandfeel.message.fnf", new Object[] { newfile });
                    }
                }
            }
        }
        else if (evt.getSource() == bRemoveDir) {
            tThemepack.setText("");
            GUIUtilities.message(this, "lookandfeel.message.restart", null);
        }
    }


    private void setupFileChooser() {
        if (fChooser == null) {
            fChooser = new JFileChooser();
            fChooser.setFileSelectionMode(JFileChooser.FILES_ONLY);
            fChooser.setMultiSelectionEnabled(false);
            fChooser.setDialogTitle(jEdit.getProperty("lookandfeel.filechooser.title"));
            fChooser.setFileFilter(new FileFilter() {
                public boolean accept(File f) {
                    return f.isDirectory() || f.getName().endsWith(".zip");
                }
                public String getDescription() {
                    return jEdit.getProperty("lookandfeel.filechooser.filefilter.description");
                }
            });
        }
    }


    private JButton bSelectDir;
    private JButton bRemoveDir;
    private JTextField tThemepack;
    private static JFileChooser fChooser = null;

}

